/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.data.set.internal.view;

import com.liferay.frontend.data.set.view.FDSView;
import com.liferay.frontend.data.set.view.FDSViewContextContributor;
import com.liferay.frontend.data.set.view.FDSViewContextContributorRegistry;
import com.liferay.frontend.data.set.view.FDSViewRegistry;
import com.liferay.frontend.data.set.view.FDSViewSerializer;
import com.liferay.portal.kernel.json.JSONArray;
import com.liferay.portal.kernel.json.JSONFactory;
import com.liferay.portal.kernel.json.JSONObject;
import com.liferay.portal.kernel.json.JSONUtil;
import com.liferay.portal.kernel.language.LanguageUtil;
import com.liferay.portal.kernel.util.ResourceBundleUtil;

import java.util.List;
import java.util.Locale;
import java.util.Map;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Marco Leo
 */
@Component(service = FDSViewSerializer.class)
public class FDSViewSerializerImpl implements FDSViewSerializer {

	@Override
	public JSONArray serialize(String fdsName, Locale locale) {
		JSONArray jsonArray = _jsonFactory.createJSONArray();

		List<FDSView> fdsViews = _fdsViewRegistry.getFDSViews(fdsName);

		for (FDSView fdsView : fdsViews) {
			JSONObject jsonObject = JSONUtil.put(
				"contentRenderer", fdsView.getContentRenderer()
			).put(
				"contentRendererModuleURL",
				fdsView.getContentRendererModuleURL()
			).put(
				"label",
				LanguageUtil.get(
					ResourceBundleUtil.getBundle(
						"content.Language", locale, getClass()),
					fdsView.getLabel())
			).put(
				"name", fdsView.getName()
			).put(
				"thumbnail", fdsView.getThumbnail()
			);

			List<FDSViewContextContributor> fdsViewContextContributors =
				_fdsViewContextContributorRegistry.
					getFDSViewContextContributors(fdsView.getContentRenderer());

			for (FDSViewContextContributor fdsViewContextContributor :
					fdsViewContextContributors) {

				Map<String, Object> fdsViewContext =
					fdsViewContextContributor.getFDSViewContext(
						fdsView, locale);

				if (fdsViewContext == null) {
					continue;
				}

				for (Map.Entry<String, Object> fdsViewContextEntry :
						fdsViewContext.entrySet()) {

					jsonObject.put(
						fdsViewContextEntry.getKey(),
						fdsViewContextEntry.getValue());
				}
			}

			jsonArray.put(jsonObject);
		}

		return jsonArray;
	}

	@Reference
	private FDSViewContextContributorRegistry
		_fdsViewContextContributorRegistry;

	@Reference
	private FDSViewRegistry _fdsViewRegistry;

	@Reference
	private JSONFactory _jsonFactory;

}