/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.data.set.internal.view.table;

import com.liferay.frontend.data.set.constants.FDSConstants;
import com.liferay.frontend.data.set.view.FDSView;
import com.liferay.frontend.data.set.view.FDSViewContextContributor;
import com.liferay.frontend.data.set.view.table.BaseTableFDSView;
import com.liferay.frontend.data.set.view.table.FDSTableSchema;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaField;
import com.liferay.petra.string.StringPool;
import com.liferay.portal.kernel.json.JSONArray;
import com.liferay.portal.kernel.json.JSONFactory;
import com.liferay.portal.kernel.json.JSONUtil;
import com.liferay.portal.kernel.language.LanguageUtil;
import com.liferay.portal.kernel.util.HashMapBuilder;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.kernel.util.Validator;

import java.util.Collections;
import java.util.Locale;
import java.util.Map;
import java.util.ResourceBundle;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Marco Leo
 */
@Component(
	property = "frontend.data.set.view.name=" + FDSConstants.TABLE,
	service = FDSViewContextContributor.class
)
public class TableFDSViewContextContributor
	implements FDSViewContextContributor {

	@Override
	public Map<String, Object> getFDSViewContext(
		FDSView fdsView, Locale locale) {

		if (fdsView instanceof BaseTableFDSView) {
			return _serialize((BaseTableFDSView)fdsView, locale);
		}

		return Collections.emptyMap();
	}

	private Map<String, Object> _serialize(
		BaseTableFDSView baseTableFDSView, Locale locale) {

		JSONArray fieldsJSONArray = _jsonFactory.createJSONArray();

		FDSTableSchema fdsTableSchema = baseTableFDSView.getFDSTableSchema(
			locale);

		Map<String, FDSTableSchemaField> fieldsMap =
			fdsTableSchema.getFDSTableSchemaFieldsMap();

		ResourceBundle resourceBundle = baseTableFDSView.getResourceBundle(
			locale);

		for (FDSTableSchemaField fdsTableSchemaField : fieldsMap.values()) {
			String label = LanguageUtil.get(
				resourceBundle, fdsTableSchemaField.getLabel());

			if (Validator.isNull(label)) {
				label = StringPool.BLANK;
			}

			fieldsJSONArray.put(
				JSONUtil.put(
					"actionId", fdsTableSchemaField.getActionId()
				).put(
					"contentRenderer", fdsTableSchemaField.getContentRenderer()
				).put(
					"contentRendererModuleURL",
					fdsTableSchemaField.getContentRendererModuleURL()
				).put(
					"expand", fdsTableSchemaField.isExpand()
				).put(
					"fieldName",
					() -> {
						String fieldName = fdsTableSchemaField.getFieldName();

						if (fieldName.contains(StringPool.PERIOD)) {
							return StringUtil.split(
								fieldName, StringPool.PERIOD);
						}

						return fieldName;
					}
				).put(
					"label", label
				).put(
					"sortable", fdsTableSchemaField.isSortable()
				).put(
					"sortingOrder",
					() -> {
						FDSTableSchemaField.SortingOrder sortingOrder =
							fdsTableSchemaField.getSortingOrder();

						if (sortingOrder != null) {
							return StringUtil.toLowerCase(
								sortingOrder.toString());
						}

						return null;
					}
				));
		}

		return HashMapBuilder.<String, Object>put(
			"schema", JSONUtil.put("fields", fieldsJSONArray)
		).build();
	}

	@Reference
	private JSONFactory _jsonFactory;

}